FTRLProx_train_spMatrix: FTRL-Proximal Linear Model Fitting Function
Description
FTRLProx_train_spMatrix estimates the weights of linear model using FTRL-Proximal Algorithm.
This function is an C++ implementation.
This function is used internally and is not intended for end-user direct usage.
Usage
FTRLProx_train_spMatrix(x, y, family, params, epoch, verbose)
Arguments
x
a transposed dgCMatrix.
y
a vector containing labels.
family
link function to be used in the model. "gaussian", "binomial" and "poisson" are avaliable.
params
a list of parameters of FTRL-Proximal Algorithm.
alpha alpha in the per-coordinate learning rate
beta beta in the per-coordinate learning rate
l1 L1 regularization parameter
l2 L2 regularization parameter
epoch
The number of iterations over training data to train the model.
verbose
logical value. Indicating if the progress bar is displayed or not.